==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/documentswitcher/kdevdocumentswitcher.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=document-open-recent
Exec=blubb
Comment=A most-recently-used document switcher for KDevPlatform.
Comment[bg]=Последен използван превключвател на документи за KDevPlatform.
Comment[bs]=Mjenjač zadnjeg korištenog dokumenta za KDevPlatformu
Comment[ca]=Un commutador del document usat més recentment per KDevPlatform.
Comment[ca@valencia]=Un commutador del document usat més recentment per KDevPlatform.
Comment[da]=En dokumentskifter til nyligt anvendte til KDevPlatform.
Comment[de]=Ein Umschalter zwischen zuletzt geöffneten Dokumenten.
Comment[el]=Ένας εναλλάκτης μεταξύ πρόσφατα χρησιμοποιημένων εγγράφων για το KDevPlatform.
Comment[en_GB]=A most-recently-used document switcher for KDevPlatform.
Comment[es]=Un cambiador del documento usado más recientemente para KDevPlatform.
Comment[et]=KDevPlatformi viimati kasutatud dokumentide vahetaja
Comment[fi]=Vaihtaa asiakirjoja niiden käyttöjärjestyksen perusteella
Comment[fr]=Un commutateur de documents parmi les plus récemment utilisés pour KDevPlatform.
Comment[gl]=Un selector entre documentos empregados recentemente para KDevPlatform.
Comment[it]=Uno scambia documento utilizzato più di recente per KDevPlatform
Comment[kk]=KDevPlatform жуырда қолданған құжаттар ауыстырғышы.
Comment[nb]=En dokumentbytter for KDevPlatform som behandler sist brukte dokumenter
Comment[nds]=En Togrieper op de tolest bruukten Dokmenten för KDevPlatform
Comment[nl]=De meest-recent-gebruikte documentwisselaar voor KDevPlatform.
Comment[pl]=Przełączanie między ostatnio używanymi dokumentacji w KDevPlatform.
Comment[pt]=Um selector dos documentos mais recentes para o KDevPlatform.
Comment[pt_BR]=Um seletor dos documentos mais recentes para o KDevPlatform.
Comment[ru]=Переключатель недавних документов для KDevPlatform.
Comment[sk]=Prepínač posledných použitých dokumentov pre KDevPlatform.
Comment[sl]=Vstavek za preklapljanje med nazadnje uporabljenimi dokumenti.
Comment[sv]=Byte till senast använda dokument för KDevelop-plattformen.
Comment[tr]=KDevPlatform için yakın zamanda en çok kullanılan belgeleri seçen bir eklenti.
Comment[uk]=Перемикач останніх використаних документів для KDevPlatform.
Comment[x-test]=xxA most-recently-used document switcher for KDevPlatform.xx
Comment[zh_CN]=KDevPlatform 最近经常使用文档的切换器。
Comment[zh_TW]=KDevPlatform 上切換最近使用的文件的切換器
Name=Most-Recently-Used Document Switcher
Name[bg]=Последният използван превключвател на документи
Name[bs]=Mjenjač zadnjeg korištenog dokumenta
Name[ca]=Commutador del document usat més recentment
Name[ca@valencia]=Commutador del document usat més recentment
Name[da]=Dokumentskifter til nyligt anvendte
Name[de]=Zuletzt-Verwendet-Dokumentumschalter
Name[el]=Εναλλάκτης μεταξύ πρόσφατα χρησιμοποιημένων εγγράφων
Name[en_GB]=Most-Recently-Used Document Switcher
Name[es]=Cambiador del documento usado más recientemente
Name[et]=Viimati kasutatud dokumentide vahetaja
Name[fi]=Viimeksi käytetty ensin -asiakirjavaihtaja
Name[fr]=Commutateur de documents parmi les plus récemment utilisés
Name[gl]=Selector entre documentos empregados recentemente
Name[it]=Scambia documento utilizzato più di recente
Name[kk]=Жуырда қолданған құжаттар ауыстырғышы
Name[nb]=Sist-brukte dokumentbytter
Name[nds]=Togrieper för de tolest bruukten Dokmenten
Name[nl]=Meest-recent-gebruikte documentwisselaar
Name[pl]=Przełączanie między ostatnio używanymi dokumentami
Name[pt]=Selector dos Documentos Usados Mais Recentemente
Name[pt_BR]=Seletor dos Documentos Usados Mais Recentemente
Name[ru]=Переключатель недавних документов
Name[sk]=Prepínač posledných použitých dokumentov
Name[sl]=Preklapljanje med nazadnje uporabljenimi dokumenti
Name[sv]=Byte till senast använda dokument
Name[tr]=Yakın Zamanda En Çok Kullanılan Belgeleri Seçici
Name[uk]=Перемикач нещодавно використаних документів
Name[x-test]=xxMost-Recently-Used Document Switcherxx
Name[zh_CN]=最近经常使用文档切换器
Name[zh_TW]=最近使用的文件切換器
GenericName=Document Switcher
GenericName[bg]=Превключвател на документи
GenericName[bs]=Mjenjač dokumenata
GenericName[ca]=Commutador de documents
GenericName[ca@valencia]=Commutador de documents
GenericName[cs]=Přepínač dokumentů 
GenericName[da]=Dokumentskifter
GenericName[de]=Dokumentumschalter
GenericName[el]=Εναλλάκτης εγγράφων
GenericName[en_GB]=Document Switcher
GenericName[es]=Cambiador de documento
GenericName[et]=Dokumendivahetaja
GenericName[fi]=Asiakirjavaihtaja
GenericName[fr]=Commutateur de documents
GenericName[gl]=Selector entre documentos
GenericName[hu]=Dokumentumváltó
GenericName[it]=Scambia documento
GenericName[ja]=文書スイッチャー
GenericName[kk]=Құжат ауыстырғышы
GenericName[nb]=Dokumentbytter
GenericName[nds]=Dokment-Togriep
GenericName[nl]=Documentenwisselaar
GenericName[pl]=Przełączanie między dokumentami
GenericName[pt]=Selector de Documentos
GenericName[pt_BR]=Seletor de Documentos
GenericName[ru]=Переключатель документов
GenericName[sk]=Prepínač dokumentov
GenericName[sl]=Preklapljanje med dokumenti
GenericName[sv]=Dokumentbyte
GenericName[tr]=Belge Seçici
GenericName[ug]=پۈتۈك ئالماشتۇرغۇچ
GenericName[uk]=Інструмент перемикання документів
GenericName[x-test]=xxDocument Switcherxx
GenericName[zh_CN]=文档切换器
GenericName[zh_TW]=文件切換器
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevdocumentswitcher
X-KDE-PluginInfo-Name=kdevdocumentswitcher
X-KDE-PluginInfo-Author=Andreas Pakulat
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI

==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/documentswitcher/kdevdocumentswitcher.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=document-open-recent
Exec=blubb
Comment=A most-recently-used document switcher for KDevPlatform.
Comment[bg]=Последен използван превключвател на документи за KDevPlatform.
Comment[bs]=Mjenjač zadnjeg korištenog dokumenta za KDevPlatformu
Comment[ca]=Un commutador del document usat més recentment per KDevPlatform.
Comment[ca@valencia]=Un commutador del document usat més recentment per KDevPlatform.
Comment[da]=En dokumentskifter til nyligt anvendte til KDevPlatform.
Comment[de]=Ein Umschalter zwischen zuletzt geöffneten Dokumenten.
Comment[el]=Ένας εναλλάκτης μεταξύ πρόσφατα χρησιμοποιημένων εγγράφων για το KDevPlatform.
Comment[en_GB]=A most-recently-used document switcher for KDevPlatform.
Comment[es]=Un cambiador del documento usado más recientemente para KDevPlatform.
Comment[et]=KDevPlatformi viimati kasutatud dokumentide vahetaja
Comment[fi]=Vaihtaa tiedostoja niiden käyttöjärjestyksen perusteella
Comment[fr]=Un commutateur de documents parmi les plus récemment utilisés pour KDevPlatform.
Comment[gl]=Un selector entre documentos empregados recentemente para KDevPlatform.
Comment[it]=Uno scambia documento utilizzato più di recente per KDevPlatform
Comment[kk]=KDevPlatform жуырда қолданған құжаттар ауыстырғышы.
Comment[nb]=En dokumentbytter for KDevPlatform som behandler sist brukte dokumenter
Comment[nds]=En Togrieper op de tolest bruukten Dokmenten för KDevPlatform
Comment[nl]=De meest-recent-gebruikte documentwisselaar voor KDevPlatform.
Comment[pl]=Przełączanie między ostatnio używanymi dokumentacji w KDevPlatform.
Comment[pt]=Um selector dos documentos mais recentes para o KDevPlatform.
Comment[pt_BR]=Um seletor dos documentos mais recentes para o KDevPlatform.
Comment[ru]=Переключатель недавних документов для KDevPlatform.
Comment[sk]=Prepínač posledných použitých dokumentov pre KDevPlatform.
Comment[sl]=Vstavek za preklapljanje med nazadnje uporabljenimi dokumenti.
Comment[sv]=Byte till senast använda dokument för KDevelop-plattformen.
Comment[tr]=KDevPlatform için yakın zamanda en çok kullanılan belgeleri seçen bir eklenti.
Comment[uk]=Перемикач останніх використаних документів для KDevPlatform.
Comment[x-test]=xxA most-recently-used document switcher for KDevPlatform.xx
Comment[zh_CN]=KDevPlatform 的最近经常使用文档的切换器。
Comment[zh_TW]=KDevPlatform 上切換最近使用的文件的切換器
Name=Most-Recently-Used Document Switcher
Name[bg]=Последният използван превключвател на документи
Name[bs]=Mjenjač zadnjeg korištenog dokumenta
Name[ca]=Commutador del document usat més recentment
Name[ca@valencia]=Commutador del document usat més recentment
Name[da]=Dokumentskifter til nyligt anvendte
Name[de]=Zuletzt-Verwendet-Dokumentumschalter
Name[el]=Εναλλάκτης μεταξύ πρόσφατα χρησιμοποιημένων εγγράφων
Name[en_GB]=Most-Recently-Used Document Switcher
Name[es]=Cambiador del documento usado más recientemente
Name[et]=Viimati kasutatud dokumentide vahetaja
Name[fi]=Viimeksi käytetty ensin -tiedostovaihtaja
Name[fr]=Commutateur de documents parmi les plus récemment utilisés
Name[gl]=Selector entre documentos empregados recentemente
Name[it]=Scambia documento utilizzato più di recente
Name[kk]=Жуырда қолданған құжаттар ауыстырғышы
Name[nb]=Sist-brukte dokumentbytter
Name[nds]=Togrieper för de tolest bruukten Dokmenten
Name[nl]=Meest-recent-gebruikte documentwisselaar
Name[pl]=Przełączanie między ostatnio używanymi dokumentami
Name[pt]=Selector dos Documentos Usados Mais Recentemente
Name[pt_BR]=Seletor dos Documentos Usados Mais Recentemente
Name[ru]=Переключатель недавних документов
Name[sk]=Prepínač posledných použitých dokumentov
Name[sl]=Preklapljanje med nazadnje uporabljenimi dokumenti
Name[sv]=Byte till senast använda dokument
Name[tr]=Yakın Zamanda En Çok Kullanılan Belgeleri Seçici
Name[uk]=Перемикач нещодавно використаних документів
Name[x-test]=xxMost-Recently-Used Document Switcherxx
Name[zh_CN]=最近经常使用文档切换器
Name[zh_TW]=最近使用的文件切換器
GenericName=Document Switcher
GenericName[bg]=Превключвател на документи
GenericName[bs]=Mjenjač dokumenata
GenericName[ca]=Commutador de documents
GenericName[ca@valencia]=Commutador de documents
GenericName[cs]=Přepínač dokumentů 
GenericName[da]=Dokumentskifter
GenericName[de]=Dokumentumschalter
GenericName[el]=Εναλλάκτης εγγράφων
GenericName[en_GB]=Document Switcher
GenericName[es]=Cambiador de documento
GenericName[et]=Dokumendivahetaja
GenericName[fi]=Tiedostovaihtaja
GenericName[fr]=Commutateur de documents
GenericName[gl]=Selector entre documentos
GenericName[hu]=Dokumentumváltó
GenericName[it]=Scambia documento
GenericName[ja]=文書スイッチャー
GenericName[kk]=Құжат ауыстырғышы
GenericName[nb]=Dokumentbytter
GenericName[nds]=Dokment-Togriep
GenericName[nl]=Documentenwisselaar
GenericName[pl]=Przełączanie między dokumentami
GenericName[pt]=Selector de Documentos
GenericName[pt_BR]=Seletor de Documentos
GenericName[ru]=Переключатель документов
GenericName[sk]=Prepínač dokumentov
GenericName[sl]=Preklapljanje med dokumenti
GenericName[sv]=Dokumentbyte
GenericName[tr]=Belge Seçici
GenericName[ug]=پۈتۈك ئالماشتۇرغۇچ
GenericName[uk]=Інструмент перемикання документів
GenericName[x-test]=xxDocument Switcherxx
GenericName[zh_CN]=文档切换器
GenericName[zh_TW]=文件切換器
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevdocumentswitcher
X-KDE-PluginInfo-Name=kdevdocumentswitcher
X-KDE-PluginInfo-Author=Andreas Pakulat
X-KDE-PluginInfo-Version=0.1
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Utilities
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Mode=GUI
